NodeWidget class

A Simple widget to display TreeNodes in the TreeView.

Includes the indentation of nodes, the addition of Lines (if applicable) and the leading NodeWidgetLeadingIcon that already expands/collapses the node and animates itself.

This widget will be wrapped in a TreeNodeScope (an inherited widget) to give access to it's TreeNode.

Take a look at the online demo.

Inheritance

Constructors

NodeWidget({Key? key, List<Widget>? content, MainAxisSize rowMainAxisSize = MainAxisSize.min, Widget leading = const NodeWidgetLeadingIcon(), VoidCallback? onTap, VoidCallback? onLongPress})
Creates a NodeWidget.
const

Properties

content → List<Widget>?
A list of widgets to display to the right of leading.
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
leading → Widget
The widget used to expand/collapse nodes.
final
onLongPress → VoidCallback?
Callback fired when the user long presses this NodeWidget.
final
onTap → VoidCallback?
Callback fired when the user taps on this NodeWidget.
final
rowMainAxisSize → MainAxisSize
The Row.mainAxisSize defaults to MainAxisSize.min.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited