TreeView class

A simple, fancy and highly customizable hierarchy visualization Widget.

Inheritance

Constructors

TreeView({Key? key, required NodeBuilder nodeBuilder, required TreeViewController controller, TreeViewTheme theme = const TreeViewTheme(), double? nodeHeight = 40.0, bool shrinkWrap = false, EdgeInsetsGeometry? padding, ScrollController? scrollController})
Creates a TreeView.
const

Properties

controller → TreeViewController
The instance of TreeController to control nodes from outside of the TreeView widget subtree.
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
nodeBuilder → NodeBuilder
Called, as needed, to build node widgets. Nodes are only built when they're scrolled into view.
final
nodeHeight → double?
The height each node will take, its more efficient (for the scrolling machinery) than letting the nodes determine their own height. (Also used by ScrollController to determine the offset of a node and scroll to it).
final
padding → EdgeInsetsGeometry?
The space around the ListView that holds the TreeNodes.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollController → ScrollController?
The ScrollController passed to ListView.controller.
final
shrinkWrap → bool
Whether the extent of the scroll view in the scrollDirection should be determined by the contents being viewed.
final
theme → TreeViewTheme
The instance of TreeViewTheme that controls the theme of the TreeView.
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _TreeViewState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

of(BuildContext context) → _TreeViewScope
Calls context.dependOnInheritedWidgetOfExactType<_TreeViewScope>() subscribing context to changes in _TreeViewScope.